==> dataframe_image-0.1.10-py3-none-any.whl: dataframe_image/_pandas_accessor.py <==
import pandas as pd
from pandas.io.formats.style import Styler

from ._screenshot import Screenshot
from .pd_html import styler2html

MAX_COLS = 30
MAX_ROWS = 100


@pd.api.extensions.register_dataframe_accessor("dfi")
class _Export:
    def __init__(self, df):
        self._df = df

    def export(
        self,
        filename,
        fontsize=14,
        max_rows=None,
        max_cols=None,
        table_conversion="chrome",
        chrome_path=None,
        dpi=None,
    ):
        return _export(
            self._df,
            filename,
            fontsize,
            max_rows,
            max_cols,
            table_conversion,
            chrome_path,
            dpi,
        )


def export(
    obj,
    filename,
    fontsize=14,
    max_rows=None,
    max_cols=None,
    table_conversion="chrome",
    chrome_path=None,
    dpi=None,
):
    return _export(
        obj, filename, fontsize, max_rows, max_cols, table_conversion, chrome_path, dpi
    )


def _export(
    obj, filename, fontsize, max_rows, max_cols, table_conversion, chrome_path, dpi
):
    is_styler = isinstance(obj, Styler)
    df = obj.data if is_styler else obj

    if table_conversion == "chrome":
        converter = Screenshot(
            max_rows=max_rows,
            max_cols=max_cols,
            chrome_path=chrome_path,
            fontsize=fontsize,
            encode_base64=False,
            limit_crop=False,
            device_scale_factor=(1 if dpi == None else dpi / 100.0),
        ).run
    elif table_conversion == "selenium":
        from .selenium_screenshot import SeleniumScreenshot

        converter = SeleniumScreenshot(
            max_rows=max_rows,
            max_cols=max_cols,
            fontsize=fontsize,
            encode_base64=False,
            limit_crop=False,
            device_scale_factor=(1 if dpi == None else dpi / 100.0),
        ).run

    else:
        from ._matplotlib_table import TableMaker

        converter = TableMaker(
            fontsize=fontsize, encode_base64=False, for_document=False, savefig_dpi=dpi
        ).run

    if df.shape[0] > MAX_ROWS and max_rows is None:
        error_msg = (
            f"Your DataFrame has more than {MAX_ROWS} rows and will produce a huge "
            "image file, possibly causing your computer to crash. Override this error "
            "by explicitly setting `max_rows`. Use -1 for all rows."
        )
        if is_styler:
            error_msg = (
                f"Your Styled DataFrame has more than {MAX_ROWS} rows and will produce "
                "a huge image file, possibly causing your computer to crash. Override "
                "this error by explicitly setting `max_rows` to -1 for all columns. "
                "Styled DataFrames are unable to select a subset of rows or columns "
                "and therefore do not work with the `max_rows` and `max_cols` parameters"
            )
        raise ValueError(error_msg)

    if df.shape[1] > MAX_COLS and max_cols is None:
        error_msg = (
            f"Your DataFrame has more than {MAX_COLS} columns and will produce a huge "
            "image file, possibly causing your computer to crash. Override this error "
            "by explicitly setting `max_cols`. Use -1 for all columns."
        )
        if is_styler:
            error_msg = (
                f"Your Styled DataFrame has more than {MAX_COLS} columns and will "
                "produce a huge image file, possibly causing your computer to crash. "
                "Override this error by explicitly setting `max_cols` to -1 for "
                "all columns. Styled DataFrames are unable to select a subset of "
                "rows or columns and therefore do not work with the `max_rows` "
                "and `max_cols` parameters"
            )
        raise ValueError(error_msg)

    if max_rows == -1:
        max_rows = None

    if max_cols == -1:
        max_cols = None

    if is_styler:
        html = styler2html(obj)
    else:
        html = obj.to_html(max_rows=max_rows, max_cols=max_cols, notebook=True)

    img_str = converter(html)

    try:
        with open(filename, "wb") as f:
            f.write(img_str)
    except TypeError as ex:
        if hasattr(filename, "write"):
            filename.write(img_str)
        else:
            raise ex


setattr(Styler, "export_png", export)

accessor_intro = """
Export a DataFrame as png to a file

Parameters
----------"""

styler_intro = """
Export a styled DataFrame as png to a file

Parameters
----------"""

doc_params = f"""
filename : str or file-like
    The file location where the image will be saved. Provide a string 
    to specify a file location on your local machine or a file-like object 
    that has a `write` method.

fontsize : int
    Font size in points

max_rows : int
    Maximum number of rows to output from DataFrame. This number is passed
    to the `to_html` DataFrame method.

    To prevent accidentally creating images with large numbers of rows,
    an error will be raised for DataFrames with more than {MAX_ROWS} rows.
    Set this parameter explicitly to override this error. Use -1 for all rows.

max_cols : int
    Maximum number of rows to output from DataFrame. This number is passed
    to the `to_html` DataFrame method.

    To prevent accidentally creating images with large numbers of columns,
    an error will be raised for DataFrames with more than {MAX_COLS} columns.
    Set this parameter explicitly to override this error. Use -1 for all columns.

table_conversion : 'chrome' or 'matplotlib', default 'chrome'
    DataFrames will be converted to png via Chrome or matplotlib. Use chrome
    unless you cannot get it to work. matplotlib provides a decent
    alternative.

chrome_path : str, default `None`
    Path to your machine's chrome executable. When `None`, it is 
    automatically found. Use this when chrome is not automatically found.

dpi : int, default `None`
    Dots per inch - Use this to change the resolution ("quality") of the image.
    
    If `table_conversion`=`matplotlib`, this value is directly passed to 
    the "savefig" method. When `None`, the figure's DPI is used.
     
    If `table_conversion`=`chrome`, the dpi value is converted to a 
    "device scale factor" but should provide the same effect. When `None`,
    the "device scale factor" is 1.
"""

export_intro = """
Export a DataFrame or Styled DataFrame as a png to a file.

Styled DataFrames cannot use max_rows or max_cols and 
cannot be exported with `table_conversion` set to 'matplotlib'.

Parameters
----------
obj : DataFrame or Styler object
    Object to export as an image
"""

_Export.export.__doc__ = accessor_intro + doc_params
export.__doc__ = export_intro + doc_params
Styler.export_png.__doc__ = styler_intro + doc_params

==> dataframe_image-0.1.11-py3-none-any.whl: dataframe_image/_pandas_accessor.py <==
import pandas as pd
from pandas.io.formats.style import Styler

from ._screenshot import Screenshot
from .pd_html import styler2html

MAX_COLS = 30
MAX_ROWS = 100


@pd.api.extensions.register_dataframe_accessor("dfi")
class _Export:
    def __init__(self, df):
        self._df = df

    def export(
        self,
        filename,
        fontsize=14,
        max_rows=None,
        max_cols=None,
        table_conversion="chrome",
        chrome_path=None,
        dpi=None,
    ):
        return _export(
            self._df,
            filename,
            fontsize,
            max_rows,
            max_cols,
            table_conversion,
            chrome_path,
            dpi,
        )


def export(
    obj,
    filename,
    fontsize=14,
    max_rows=None,
    max_cols=None,
    table_conversion="chrome",
    chrome_path=None,
    dpi=None,
):
    return _export(
        obj, filename, fontsize, max_rows, max_cols, table_conversion, chrome_path, dpi
    )


def _export(
    obj, filename, fontsize, max_rows, max_cols, table_conversion, chrome_path, dpi
):
    is_styler = isinstance(obj, Styler)
    df = obj.data if is_styler else obj
    if table_conversion == "html2image":
        from ._html2image import Html2ImageConverter
        converter = Html2ImageConverter(
            max_rows=max_rows,
            max_cols=max_cols,
            chrome_path=chrome_path,
            fontsize=fontsize,
            encode_base64=False,
            limit_crop=False,
            device_scale_factor=(1 if dpi == None else dpi / 100.0),
        ).run
    elif table_conversion == "chrome":
        converter = Screenshot(
            max_rows=max_rows,
            max_cols=max_cols,
            chrome_path=chrome_path,
            fontsize=fontsize,
            encode_base64=False,
            limit_crop=False,
            device_scale_factor=(1 if dpi == None else dpi / 100.0),
        ).run
    elif table_conversion == "selenium":
        from .selenium_screenshot import SeleniumScreenshot

        converter = SeleniumScreenshot(
            max_rows=max_rows,
            max_cols=max_cols,
            fontsize=fontsize,
            encode_base64=False,
            limit_crop=False,
            device_scale_factor=(1 if dpi == None else dpi / 100.0),
        ).run

    else:
        from ._matplotlib_table import TableMaker

        converter = TableMaker(
            fontsize=fontsize, encode_base64=False, for_document=False, savefig_dpi=dpi
        ).run

    if df.shape[0] > MAX_ROWS and max_rows is None:
        error_msg = (
            f"Your DataFrame has more than {MAX_ROWS} rows and will produce a huge "
            "image file, possibly causing your computer to crash. Override this error "
            "by explicitly setting `max_rows`. Use -1 for all rows."
        )
        if is_styler:
            error_msg = (
                f"Your Styled DataFrame has more than {MAX_ROWS} rows and will produce "
                "a huge image file, possibly causing your computer to crash. Override "
                "this error by explicitly setting `max_rows` to -1 for all columns. "
                "Styled DataFrames are unable to select a subset of rows or columns "
                "and therefore do not work with the `max_rows` and `max_cols` parameters"
            )
        raise ValueError(error_msg)

    if df.shape[1] > MAX_COLS and max_cols is None:
        error_msg = (
            f"Your DataFrame has more than {MAX_COLS} columns and will produce a huge "
            "image file, possibly causing your computer to crash. Override this error "
            "by explicitly setting `max_cols`. Use -1 for all columns."
        )
        if is_styler:
            error_msg = (
                f"Your Styled DataFrame has more than {MAX_COLS} columns and will "
                "produce a huge image file, possibly causing your computer to crash. "
                "Override this error by explicitly setting `max_cols` to -1 for "
                "all columns. Styled DataFrames are unable to select a subset of "
                "rows or columns and therefore do not work with the `max_rows` "
                "and `max_cols` parameters"
            )
        raise ValueError(error_msg)

    if max_rows == -1:
        max_rows = None

    if max_cols == -1:
        max_cols = None

    if is_styler:
        html = styler2html(obj)
    else:
        html = obj.to_html(max_rows=max_rows, max_cols=max_cols, notebook=True)

    img_str = converter(html)

    try:
        with open(filename, "wb") as f:
            f.write(img_str)
    except TypeError as ex:
        if hasattr(filename, "write"):
            filename.write(img_str)
        else:
            raise ex


setattr(Styler, "export_png", export)

accessor_intro = """
Export a DataFrame as png to a file

Parameters
----------"""

styler_intro = """
Export a styled DataFrame as png to a file

Parameters
----------"""

doc_params = f"""
filename : str or file-like
    The file location where the image will be saved. Provide a string 
    to specify a file location on your local machine or a file-like object 
    that has a `write` method.

fontsize : int
    Font size in points

max_rows : int
    Maximum number of rows to output from DataFrame. This number is passed
    to the `to_html` DataFrame method.

    To prevent accidentally creating images with large numbers of rows,
    an error will be raised for DataFrames with more than {MAX_ROWS} rows.
    Set this parameter explicitly to override this error. Use -1 for all rows.

max_cols : int
    Maximum number of rows to output from DataFrame. This number is passed
    to the `to_html` DataFrame method.

    To prevent accidentally creating images with large numbers of columns,
    an error will be raised for DataFrames with more than {MAX_COLS} columns.
    Set this parameter explicitly to override this error. Use -1 for all columns.

table_conversion : 'chrome' or 'matplotlib', default 'chrome'
    DataFrames will be converted to png via Chrome or matplotlib. Use chrome
    unless you cannot get it to work. matplotlib provides a decent
    alternative.

chrome_path : str, default `None`
    Path to your machine's chrome executable. When `None`, it is 
    automatically found. Use this when chrome is not automatically found.

dpi : int, default `None`
    Dots per inch - Use this to change the resolution ("quality") of the image.
    
    If `table_conversion`=`matplotlib`, this value is directly passed to 
    the "savefig" method. When `None`, the figure's DPI is used.
     
    If `table_conversion`=`chrome`, the dpi value is converted to a 
    "device scale factor" but should provide the same effect. When `None`,
    the "device scale factor" is 1.
"""

export_intro = """
Export a DataFrame or Styled DataFrame as a png to a file.

Styled DataFrames cannot use max_rows or max_cols and 
cannot be exported with `table_conversion` set to 'matplotlib'.

Parameters
----------
obj : DataFrame or Styler object
    Object to export as an image
"""

_Export.export.__doc__ = accessor_intro + doc_params
export.__doc__ = export_intro + doc_params
Styler.export_png.__doc__ = styler_intro + doc_params
